@@ -86,6 +86,7 @@ CMD_DECL(compress)
 CMD_DECL(create)
 CMD_DECL(dimension_add)
 CMD_DECL(dimension_extract)
+CMD_DECL(dimension_flatten)
 CMD_DECL(dimension_merge)
 CMD_DECL(dimension_reorder)
 CMD_DECL(dimension_reverse)
@@ -94,13 +95,17 @@ CMD_DECL(extract)
 CMD_DECL(fill)
 CMD_DECL(from_dcmtk)
 CMD_DECL(from_exr)
+CMD_DECL(from_ffmpeg)
 CMD_DECL(from_gdal)
 CMD_DECL(from_magick)
 CMD_DECL(from_mat)
 CMD_DECL(from_netpbm)
+CMD_DECL(from_pcd)
 CMD_DECL(from_pfs)
+CMD_DECL(from_ply)
 CMD_DECL(from_rat)
 CMD_DECL(from_raw)
+CMD_DECL(from_sndfile)
 CMD_DECL(gui)
 CMD_DECL(help)
 CMD_DECL(info)
@@ -116,9 +121,12 @@ CMD_DECL(to_gdal)
 CMD_DECL(to_magick)
 CMD_DECL(to_mat)
 CMD_DECL(to_netpbm)
+CMD_DECL(to_pcd)
 CMD_DECL(to_pfs)
+CMD_DECL(to_ply)
 CMD_DECL(to_rat)
 CMD_DECL(to_raw)
+CMD_DECL(to_sndfile)
 CMD_DECL(uncompress)
 CMD_DECL(version)
 
@@ -136,6 +144,7 @@ static cmd_t cmds[] =
     CMD("create",            array,      create,            true,          BUILTIN),
     CMD("dimension-add",     dimension,  dimension_add,     true,          BUILTIN),
     CMD("dimension-extract", dimension,  dimension_extract, true,          BUILTIN),
+    CMD("dimension-flatten", dimension,  dimension_flatten, true,          BUILTIN),
     CMD("dimension-merge",   dimension,  dimension_merge,   true,          BUILTIN),
     CMD("dimension-reorder", dimension,  dimension_reorder, true,          BUILTIN),
     CMD("dimension-reverse", dimension,  dimension_reverse, true,          BUILTIN),
@@ -144,13 +153,17 @@ static cmd_t cmds[] =
     CMD("fill",              array,      fill,              true,          BUILTIN),
     CMD("from-dcmtk",        conversion, from_dcmtk,        WITH_DCMTK,    "conv-dcmtk"),
     CMD("from-exr",          conversion, from_exr,          WITH_EXR,      "conv-exr"),
+    CMD("from-ffmpeg",       conversion, from_ffmpeg,       WITH_FFMPEG,   "conv-ffmpeg"),
     CMD("from-gdal",         conversion, from_gdal,         WITH_GDAL,     "conv-gdal"),
     CMD("from-magick",       conversion, from_magick,       WITH_MAGICK,   "conv-magick"),
     CMD("from-mat",          conversion, from_mat,          WITH_MAT,      "conv-mat"),
     CMD("from-netpbm",       conversion, from_netpbm,       WITH_NETPBM,   "conv-netpbm"),
+    CMD("from-pcd",          conversion, from_pcd,          WITH_PCD,      "conv-pcd"),
     CMD("from-pfs",          conversion, from_pfs,          WITH_PFS,      "conv-pfs"),
-    CMD("from-rat",          conversion, from_rat,          true,          "conv-rat"),
-    CMD("from-raw",          conversion, from_raw,          true,          "conv-raw"),
+    CMD("from-ply",          conversion, from_ply,          WITH_PLY,      "conv-ply"),
+    CMD("from-rat",          conversion, from_rat,          WITH_RAT,      "conv-rat"),
+    CMD("from-raw",          conversion, from_raw,          WITH_RAW,      "conv-raw"),
+    CMD("from-sndfile",      conversion, from_sndfile,      WITH_SNDFILE,  "conv-sndfile"),
     CMD("gui",               misc,       gui,               WITH_QT,       "gui"),
     CMD("help",              misc,       help,              true,          BUILTIN),
     CMD("info",              array,      info,              true,          BUILTIN),
@@ -166,9 +179,12 @@ static cmd_t cmds[] =
     CMD("to-magick",         conversion, to_magick,         WITH_MAGICK,   "conv-magick"),
     CMD("to-mat",            conversion, to_mat,            WITH_MAT,      "conv-mat"),
     CMD("to-netpbm",         conversion, to_netpbm,         WITH_NETPBM,   "conv-netpbm"),
+    CMD("to-pcd",            conversion, to_pcd,            WITH_PCD,      "conv-pcd"),
     CMD("to-pfs",            conversion, to_pfs,            WITH_PFS,      "conv-pfs"),
-    CMD("to-rat",            conversion, to_rat,            true,          "conv-rat"),
-    CMD("to-raw",            conversion, to_raw,            true,          "conv-raw"),
+    CMD("to-ply",            conversion, to_ply,            WITH_PLY,      "conv-ply"),
+    CMD("to-rat",            conversion, to_rat,            WITH_RAT,      "conv-rat"),
+    CMD("to-raw",            conversion, to_raw,            WITH_RAW,      "conv-raw"),
+    CMD("to-sndfile",        conversion, to_sndfile,        WITH_SNDFILE,  "conv-sndfile"),
     CMD("uncompress",        array,      uncompress,        true,          BUILTIN),
     CMD("version",           misc,       version,           true,          BUILTIN),
 };
