@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011
+ * Copyright (C) 2010, 2011, 2012
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -668,7 +668,7 @@ const std::string &array_loop_t::filename_out() throw ()
 
 bool array_loop_t::read(gta::header &header_in, std::string &name_in)
 {
-    while (!fio::has_more(_file_in))
+    while (!fio::has_more(_file_in, filename_in()))
     {
         if (_filenames_in.size() == 0)
         {
